@@ -1,7 +1,9 @@
 import re
-from typing import Dict, List, NamedTuple, Optional, Union
+from typing import Any, Dict, List, NamedTuple, Optional, Union
 from urllib.parse import urlparse, urlunparse
+from warnings import warn
 from .filenames import parse_filename
+from .util import basejoin
 
 
 class Link(NamedTuple):
@@ -38,12 +40,19 @@ class DistributionPackage(NamedTuple):
 
     .. versionchanged:: 0.9.0
         `has_metadata`, `metadata_url`, and `metadata_digests` attributes added
+
+    .. versionchanged:: 0.10.0
+        `digests` attribute added
     """
 
     #: The basename of the package file
     filename: str
 
-    #: The URL from which the package file can be downloaded
+    #: The URL from which the package file can be downloaded, with any hash
+    #: digest fragment removed
+    #:
+    #: .. versionchanged:: 0.10.0
+    #:     Hash digest fragments are now stripped from the URL
     url: str
 
     #: The name of the project (as extracted from the filename), or `None` if
@@ -70,7 +79,7 @@ class DistributionPackage(NamedTuple):
     #: which the package can be installed
     requires_python: Optional[str]
 
-    #: Whether the package file is accompanied by a PGP signature file.   This
+    #: Whether the package file is accompanied by a PGP signature file.  This
     #: is `None` if the package repository does not report such information.
     #:
     #: .. versionchanged:: 0.7.0
@@ -84,11 +93,22 @@ class DistributionPackage(NamedTuple):
     #: yanked; otherwise, it is `None`.
     yanked: Optional[str]
 
+    #: A collection of hash digests for the file as a `dict` mapping hash
+    #: algorithm names to hex-encoded digest strings
+    digests: Dict[str, str]
+
+    #: Whether the package file is accompanied by a Core Metadata file.  This
+    #: is `None` if the package repository does not report such information.
+    #:
+    #: .. versionchanged:: 0.10.0
+    #:     Will now be `None` if not specified by repository
+    has_metadata: Optional[bool] = None
+
     #: If the package repository provides a Core Metadata file for the package,
     #: this is a (possibly empty) `dict` of digests of the file, given as a
     #: mapping from hash algorithm names to hex-encoded digest strings;
     #: otherwise, it is `None`
-    metadata_digests: Optional[Dict[str, str]]
+    metadata_digests: Optional[Dict[str, str]] = None
 
     @property
     def sig_url(self) -> str:
@@ -104,29 +124,33 @@ class DistributionPackage(NamedTuple):
         return urlunparse((u[0], u[1], u[2] + ".asc", "", "", ""))
 
     @property
-    def has_metadata(self) -> bool:
-        """Whether the package file is accompanied by a Core Metadata file"""
-        return self.metadata_digests is not None
+    def metadata_url(self) -> str:
+        """
+        The URL of the package file's Core Metadata file, if it exists; cf.
+        `has_metadata`
 
-    @property
-    def metadata_url(self) -> Optional[str]:
+        .. versionchanged:: 0.10.0
+            Now always defined; would previously be `None` if `has_metadata`
+            was false
         """
-        If the package repository provides a Core Metadata file for the
-        package, this is the URL for that file; otherwise, it is `None`.
-        """
-        if self.has_metadata:
-            u = urlparse(self.url)
-            return urlunparse((u[0], u[1], u[2] + ".metadata", "", "", ""))
-        else:
-            return None
+        u = urlparse(self.url)
+        return urlunparse((u[0], u[1], u[2] + ".metadata", "", "", ""))
 
     def get_digests(self) -> Dict[str, str]:
         """
-        Extracts the hash digests from the package file's URL and returns a
-        `dict` mapping hash algorithm names to hex-encoded digest strings
+        Returns the hash digests for the file as a `dict` mapping hash
+        algorithm names to hex-encoded digest strings
+
+        .. deprecated:: 0.10.0
+
+            Use `digests` instead
         """
-        name, sep, value = urlparse(self.url).fragment.partition("=")
-        return {name: value} if value else {}
+        warn(
+            "The get_digests() method is deprecated.  Use the `digests`"
+            " attribute instead.",
+            DeprecationWarning,
+        )
+        return self.digests
 
     @classmethod
     def from_link(
@@ -151,6 +175,10 @@ class DistributionPackage(NamedTuple):
             return value
 
         project, version, pkg_type = parse_filename(link.text, project_hint)
+        urlbits = urlparse(link.url)
+        dgst_name, _, dgst_value = urlbits.fragment.partition("=")
+        digests = {dgst_name: dgst_value} if dgst_value else {}
+        url = urlunparse(urlbits._replace(fragment=""))
         has_sig: Optional[bool]
         gpg_sig = get_str_attrib("data-gpg-sig")
         if gpg_sig is not None:
@@ -168,14 +196,81 @@ class DistributionPackage(NamedTuple):
             metadata_digests = None
         return cls(
             filename=link.text,
-            url=link.url,
+            url=url,
             has_sig=has_sig,
             requires_python=get_str_attrib("data-requires-python"),
             project=project,
             version=version,
             package_type=pkg_type,
             yanked=get_str_attrib("data-yanked"),
+            digests=digests,
             metadata_digests=metadata_digests,
+            has_metadata=metadata_digests is not None,
+        )
+
+    @classmethod
+    def from_pep691_details(
+        cls,
+        data: Any,
+        project_hint: Optional[str] = None,
+        base_url: Optional[str] = None,
+    ) -> "DistributionPackage":
+        """
+        .. versionadded:: 0.10.0
+
+        Construct a `DistributionPackage` from an object taken from the
+        ``"files"`` field of a :pep:`691` project detail response.
+
+        :param data: a file dictionary
+        :param Optional[str] project_hint: Optionally, the expected value for
+            the project name (usually the name of the project page on which the
+            link was found).  The name does not need to be normalized.
+        :param Optional[str] base_url: an optional URL to join to the front of
+            a relative file URL (usually the URL of the page being parsed)
+        :rtype: DistributionPackage
+        :raises TypeError: if ``data`` is not a `dict`
+        """
+        if not isinstance(data, dict):
+            raise TypeError(
+                f"JSON file details object is {type(data)} instead of a dict"
+            )
+        project, version, pkg_type = parse_filename(data["filename"], project_hint)
+        yankfield = data.get("yanked", False)
+        yanked: Optional[str]
+        if yankfield is True:
+            yanked = ""
+        elif yankfield is False:
+            yanked = None
+        else:
+            if not isinstance(yankfield, str):
+                raise TypeError(f'"yanked" field is not a str: {yankfield!r}')
+            yanked = yankfield
+        mddigest = data.get("dist-info-metadata")
+        metadata_digests: Optional[Dict[str, str]]
+        if mddigest is None:
+            has_metadata = None
+            metadata_digests = None
+        elif mddigest is False:
+            has_metadata = False
+            metadata_digests = None
+        elif mddigest is True:
+            has_metadata = True
+            metadata_digests = {}
+        else:
+            has_metadata = True
+            metadata_digests = mddigest
+        return cls(
+            filename=data["filename"],
+            url=basejoin(base_url, data["url"]),
+            has_sig=data.get("gpg-sig"),
+            requires_python=data.get("requires-python"),
+            project=project,
+            version=version,
+            package_type=pkg_type,
+            yanked=yanked,
+            digests=data["hashes"],
+            metadata_digests=metadata_digests,
+            has_metadata=has_metadata,
         )
 
 
