@@ -1,4 +1,5 @@
 from io import StringIO
+from typing import List, Optional
 import pytest
 from pypi_simple import (
     SUPPORTED_REPOSITORY_VERSION,
@@ -129,7 +130,7 @@ from pypi_simple import (
             ],
         ),
         # I'm not sure if this is how HTML is supposed to work, but it is how
-        # pip works: <https://git.io/fAVZF>
+        # pip works: <https://github.com/pypa/pip/blob/18.0/src/pip/_internal/index.py#L878>
         (
             """
             <html>
@@ -430,7 +431,9 @@ from pypi_simple import (
         ),
     ],
 )
-def test_parse_links_stream(html, base_url, links):
+def test_parse_links_stream(
+    html: str, base_url: Optional[str], links: List[Link]
+) -> None:
     assert list(parse_links_stream(StringIO(html), base_url)) == links
 
 
@@ -627,7 +630,9 @@ def test_parse_links_stream(html, base_url, links):
         ),
     ],
 )
-def test_parse_links_stream_iterable_bytes(htmlseq, charset, links):
+def test_parse_links_stream_iterable_bytes(
+    htmlseq: List[bytes], charset: Optional[str], links: List[Link]
+) -> None:
     assert list(parse_links_stream(htmlseq, http_charset=charset)) == links
 
 
@@ -688,7 +693,7 @@ def test_parse_links_stream_iterable_bytes(htmlseq, charset, links):
         ),
     ],
 )
-def test_parse_links_stream_unsupported_version(html, version):
+def test_parse_links_stream_unsupported_version(html: str, version: str) -> None:
     with pytest.raises(UnsupportedRepoVersionError) as excinfo:
         list(parse_links_stream(StringIO(html)))
     assert excinfo.value.declared_version == version
