@@ -1,3 +1,4 @@
+from typing import Dict, List, Optional, Tuple
 import pytest
 from pypi_simple import (
     SUPPORTED_REPOSITORY_VERSION,
@@ -145,7 +146,7 @@ from pypi_simple import (
             ),
         ),
         # I'm not sure if this is how HTML is supposed to work, but it is how
-        # pip works: <https://git.io/fAVZF>
+        # pip works: <https://github.com/pypa/pip/blob/18.0/src/pip/_internal/index.py#L878>
         (
             """
             <html>
@@ -493,11 +494,13 @@ from pypi_simple import (
         ),
     ],
 )
-def test_parse_repo_links(html, base_url, links):
+def test_parse_repo_links(
+    html: str, base_url: Optional[str], links: Tuple[Dict[str, str], List[Link]]
+) -> None:
     assert parse_repo_links(html, base_url) == links
 
 
-def test_parse_repo_links_unsupported_version():
+def test_parse_repo_links_unsupported_version() -> None:
     with pytest.raises(UnsupportedRepoVersionError) as excinfo:
         parse_repo_links(
             """
